@@ -1,4 +1,3 @@
-# -*- mode:python; coding:utf-8 -*-
 # Copyright (c) 2021, 2022 IBM Corp. All rights reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -65,10 +64,10 @@ class LockerPushError(Exception):
 
     def __str__(self):
         """Display the error as a string."""
-        msg = 'Push to remote locker failed.\n'
+        msg = "Push to remote locker failed.\n"
         if self.push_info:
             msg += (
-                f'       Summary: {self.push_info.summary}'
-                f'       Error Flags: {self.push_info.flags}'
+                f"       Summary: {self.push_info.summary}"
+                f"       Error Flags: {self.push_info.flags}"
             )
         return msg
